@@ -368,10 +368,10 @@ def last_file(folder: Union[PathLike, str, bytes] = '.', filter: str = None) ->
     return files[0] if files else None
 
 
-class Removable(PathLike):
+class Removable(object):
     """ Class to include enter and exit methods for removable files. """
     @property
-    def files(self) -> Tuple[Union[str, bytes]]:
+    def files(self) -> Tuple[Union[str, PathLike, bytes]]:
         return self.__files
 
     @property
@@ -387,17 +387,12 @@ class Removable(PathLike):
         self.__ignore_errors = ignore_errors
         self.__recursive = recursive
 
-    def __enter__(self) -> None:
+    def __enter__(self) -> object:
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb) -> None:
         remove_files(*self.__files, ignore_errors=self.__ignore_errors, recursive=self.__recursive)
 
-    def __fspath__(self):
-        if len(self.__files) != 1:
-            raise ValueError('To use this class as a PathLike instance it is necessary to have just exactly one file.')
-        return self.__files[0]
-
     def __repr__(self) -> str:
         return str(self.__files)
 
@@ -420,7 +415,16 @@ def removable_files(*files: Union[PathLike, str, bytes], ignore_errors: bool = F
     return Removable(*files, ignore_errors=ignore_errors, recursive=recursive)
 
 
-def removable_tmp(folder: bool = False, suffix: str = None, prefix: str=None) -> PathLike:
+class RemovableTemp(Removable, PathLike):
+    def __init__(self, folder: bool = False, suffix: str = '', prefix: str = ''):
+        self.__tmp = mkdtemp(suffix=suffix, prefix=prefix) if folder else mktemp(suffix=suffix, prefix=prefix)
+        Removable.__init__(self, self.__tmp, recursive=folder, ignore_errors=True)
+
+    def __fspath__(self) -> str:
+        return self.__tmp
+
+
+def removable_tmp(folder: bool = False, suffix: str = '', prefix: str = '') -> PathLike:
     """ This function is used with "with" python command. As following:
 
     .. code-block:: python
@@ -433,8 +437,7 @@ def removable_tmp(folder: bool = False, suffix: str = None, prefix: str=None) ->
 
     :return: A object with enter and exit methods.
     """
-    tmp = mkdtemp(suffix=suffix, prefix=prefix) if folder else mktemp(suffix=suffix, prefix=prefix)
-    return Removable(tmp, recursive=folder)
+    return RemovableTemp(folder, suffix, prefix)
 
 
 def output_file_path(folder: Union[PathLike, str, bytes] = '.', suffix: str = '', timestamp: bool = True, **kwargs) -> str:
